/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#include "cmdecho.h"
#include "shellinstance.h"
#include "iosystem.h"
#include <stdlib.h>

#include "debugnew.h"

namespace shellp
{

CmdEcho::CmdEcho(const std::string &cmdName) : ShellCommand(cmdName)
{
	m_pEchoStr = new ShellCmdStringArg("string");
	m_pEchoStr->setDescription("String to be displayed.");
	m_pEchoStr->setDefault("");
	addArgument(m_pEchoStr);
	
	setDescription("Displays a string.");
}

CmdEcho::~CmdEcho()
{
	delete m_pEchoStr;
}

bool CmdEcho::execute()
{
	ShellInstance *pInst = ShellInstance::getInstance();
	IOSystem *m_pIOSys = pInst->getIOSystem();

	m_pIOSys->writeOutputLine(m_pEchoStr->getValue());

	return true;
}

} // end namespace
