/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#include "cmdexport.h"
#include "shellinstance.h"
#include "shellcmdstringarg.h"
#include "shellcmdboolarg.h"
#include <stdio.h>

namespace shellp
{

CmdExport::CmdExport(const std::string &cmdName) : ShellCommand(cmdName)
{
	m_pFileNameArg = new ShellCmdStringArg("filename");
	m_pFileNameArg->setDescription("Name of the file to which the commands should be exported.");
	addArgument(m_pFileNameArg);

	m_pAppendArg = new ShellCmdBoolArg("append");
	m_pAppendArg->setDescription("If enabled and an existing file is specified, the data will be appended. Otherwise, the file is overwritten.");
	addArgument(m_pAppendArg);

	setDescription("Export the commands which have been executed so far to a text file.");
}

CmdExport::~CmdExport()
{
	delete m_pFileNameArg;
	delete m_pAppendArg;
}

bool CmdExport::execute()
{
	ShellInstance *pInst = ShellInstance::getInstance();
	std::string fileName = m_pFileNameArg->getValue();
	FILE *pFile = 0;

	if (m_pAppendArg->getValue())
		pFile = fopen(fileName.c_str(), "at");
	else
		pFile = fopen(fileName.c_str(), "wt");

	if (pFile == 0)
	{
		setErrorString("Unable to open the specified file");
		return false;
	}

	std::vector<std::string> lines = pInst->getCommandLines();

	for (int i = 0 ; i < lines.size() ; i++)
		fprintf(pFile, "%s\n", lines[i].c_str());

	fclose(pFile);

	return true;
}

} // end namespace

