// TODO: windows version
#ifdef WIN32

#include <Windows.h>
#include "dirutil.h"
#include <vector>

bool changeDirectory(const std::string &dir)
{
	if (!SetCurrentDirectory(dir.c_str()))
		return false;
	return true;
}

std::string getCurrentDirectory()
{
	DWORD neededSize = GetCurrentDirectory(0, 0);

	std::vector<char> buf(neededSize+1);
	if (GetCurrentDirectory(buf.size(), &(buf[0])) == 0)
		return "UNKNOWN_DIRECTORY";
	return std::string(&(buf[0]));
}


#else
#include "dirutil.h"
#include <unistd.h>
#include <errno.h>
#include <vector>

bool changeDirectory(const std::string &dir)
{
	if (chdir(dir.c_str()) != 0)
		return false;
	return true;
}

std::string getCurrentDirectory()
{
	std::vector<char> buf(4096);
	bool done = false;

	while (!done)
	{
		if (getcwd(&(buf[0]), buf.size()))
			done = true; // ok, fits in the buffer
		else
		{
			if (errno == ERANGE)
			{
				size_t s = buf.size();
				s += 4096;

				buf.resize(s);
			}
			else // don't know what to do in this case
			{
				return "UNKNOWN_DIRECTORY";
			}
		}
	}

	return std::string(&(buf[0]));
}

#endif // WIN32