/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#ifndef SHELLP_SHELLCMDCHOICEARG_H

#define SHELLP_SHELLCMDCHOICEARG_H

#include "shellconfig.h"
#include "shellcmdarg.h"
#include <vector>

namespace shellp
{

class SHELLP_IMPORTEXPORT ShellCmdChoiceArg : public ShellCmdArg
{
public:
	ShellCmdChoiceArg(const std::string &argName);
	ShellCmdChoiceArg(const std::string &argName, const std::string &defaultValue);
	~ShellCmdChoiceArg();

	// 'value' should be positive
	bool registerChoice(const std::string &choiceName, const std::string &choiceDescription, int value);

	bool parse(const std::string &arg);
	int getValue() const							{ return m_val; }

	int getNumberOfChoices() const						{ return m_choices.size(); }
	bool getChoiceInfo(int i, std::string &name, std::string &description, int &value) const;
private:
	int m_val;

	class ChoiceInfo
	{
	public:
		ChoiceInfo(const std::string &choiceName, const std::string &choiceDescription, int value)
		{
			m_choiceName = choiceName;
			m_choiceDescription = choiceDescription;
			m_value = value;
		}

		std::string getName() const					{ return m_choiceName; }
		std::string getDescription() const				{ return m_choiceDescription; }
		int getValue() const						{ return m_value; }
	private:
		std::string m_choiceName, m_choiceDescription;
		int m_value;
	};

	std::vector<ChoiceInfo> m_choices;
};

} // end namespace

#endif // SHELLP_SHELLCMDCHOICEARG_H

