/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#ifndef SHELLP_SHELLCOMMAND_H

#define SHELLP_SHELLCOMMAND_H

#include "shellconfig.h"
#include "shellcmdarg.h"
#include <errut/errorbase.h>
#include <string>
#include <vector>

namespace shellp
{

class SHELLP_IMPORTEXPORT ShellCommand : public errut::ErrorBase
{
protected:
	ShellCommand(const std::string &commandName);
public:
	virtual ~ShellCommand();
	
	std::vector<ShellCmdArg *> getArguments()	 				{ return m_argList; }
	virtual bool execute() = 0;
	
	void setDescription(const std::string &d)					{ m_description = d; }
	std::string getDescription() const						{ return m_description; }
protected:
	void addArgument(ShellCmdArg *pArg)						{ m_argList.push_back(pArg); }
private:
	std::vector<ShellCmdArg *> m_argList;
	std::string m_description;
};

} // end namespace

#endif // SHELLP_SHELLCOMMAND_H

